@@ -36,11 +36,11 @@ RDF::LinkedData - A simple Linked Data implementation
 
 =head1 VERSION
 
-Version 0.52
+Version 0.54
 
 =cut
 
-our $VERSION = '0.52';
+our $VERSION = '0.54';
 
 
 =head1 SYNOPSIS
@@ -121,7 +121,7 @@ sub BUILD {
  	if ($self->has_void_config) {
 		$self->logger->debug('VoID config found with parameters: ' . Dumper($self->void_config) );
 
-		unless (can_load( modules => { 'RDF::Generator::Void' => 0.02 })) {
+		unless (can_load( modules => { 'RDF::Generator::Void' => 0.04 })) {
 			throw Error -text => "RDF::Generator::Void not installed. Please install or remove its configuration.";
 		}
 		my $dataset_uri = (defined($self->void_config->{dataset_uri}))
@@ -484,22 +484,43 @@ sub _void_content {
 	my $fragment = $dataset_uri->fragment;
 	$dataset_uri =~ s/(\#$fragment)$//;
 	if ($uri->eq($dataset_uri)) {
-		if ($self->void_config->{urispace}) {
-			$generator->urispace($self->void_config->{urispace});
-		} else {
-			$generator->urispace($self->base_uri);
-		}
-		if ($self->namespaces_as_vocabularies) {
-			$generator->add_vocabularies(values(%{$self->namespaces}));
-		}
-		if ($self->has_endpoint) {
-			$generator->add_endpoints($self->base_uri . $endpoint_path);
-		}
-		if ($self->has_last_etag && ($self->last_etag ne $self->current_etag)) {
-			$self->_clear_voidmodel;
-		}
-		unless ($self->_has_voidmodel) {
-			$self->_voidmodel($generator->generate);
+	  if ($self->void_config->{urispace}) {
+		 $generator->urispace($self->void_config->{urispace});
+	  } else {
+		 $generator->urispace($self->base_uri);
+	  }
+	  if ($self->namespaces_as_vocabularies) {
+		 $generator->add_vocabularies(values(%{$self->namespaces}));
+	  }
+	  if ($self->has_endpoint) {
+		 $generator->add_endpoints($self->base_uri . $endpoint_path);
+	  }
+	  if ($self->void_config->{licenses}) {
+		 $generator->add_licenses($self->void_config->{licenses});
+	  }
+	  foreach my $title (@{$self->void_config->{titles}}) {
+		 $generator->add_titles(literal(@{$title}));
+	  }
+	  if ($self->void_config->{endpoints}) {
+		 $generator->add_endpoints(literal($self->void_config->{endpoints}));
+	  }
+	  if ($self->void_config->{vocabularies}) {
+		 $generator->add_vocabularies($self->void_config->{vocabularies});
+	  }
+
+	  if ($self->has_last_etag && ($self->last_etag ne $self->current_etag)) {
+		 $self->_clear_voidmodel; 
+	  }
+
+	  my $file_model = undef;
+	  if ($self->void_config->{add_void}) {
+		 $file_model = RDF::Trine::Model->temporary_model;
+		 my $parser = RDF::Trine::Parser->new($self->void_config->{add_void}->{syntax});
+		 $parser->parse_file_into_model($self->base_uri, $self->void_config->{add_void}->{file}, $file_model);
+	  }
+
+	   unless ($self->_has_voidmodel) {
+			$self->_voidmodel($generator->generate($file_model));
 			$self->last_etag($self->current_etag);
 		}
 		my ($ct, $s) = $self->_negotiate($self->request->headers);
@@ -510,7 +531,7 @@ sub _void_content {
 		} else {
 			# For (X)HTML, we need to do extra work
 			my $gen = RDF::RDFa::Generator->new( style => 'HTML::Pretty',
-															 title => 'VoID Description',
+															 title => $self->void_config->{pagetitle} || 'VoID Description',
 															 base => $self->base_uri,
 															 namespaces => $self->namespaces);
 			my $writer = HTML::HTML5::Writer->new( markup => 'xhtml', doctype => DOCTYPE_XHTML_RDFA );
